@@ -199,7 +199,7 @@ class ConfigCmd:
             if 'full-feature' in self._xml_input.findall('simulator/optimal-ranker')[0].attrib:
                 self.full_feature = self._xml_input.findall('simulator/optimal-ranker')[0].attrib['full-feature']
             if 'lmbda' in self._xml_input.findall('simulator/optimal-ranker')[0].attrib:
-                self.lmbda = self._xml_input.findall('simulator/optimal-ranker')[0].attrib['lmbda']
+                self.lmbda = float(self._xml_input.findall('simulator/optimal-ranker')[0].attrib['lmbda'])
 
         self.optimal_reward_function = 'naive_relevance'
         if self._xml_input.findall('simulator/optimal-reward-function'):
