@@ -32,7 +32,7 @@ class OnlineSimulator():
         # overall_clicks = np.zeros((len(rankers), config.rounds))
         for i in tqdm(range(config.rounds)):
             # Select batch of n_users_per_round users
-            user_ids = np.random.choice(range(dataObj.n_users), config.n_users_per_round, replace=False)
+            user_ids = np.array([dataObj.userid_mapped_data['4486'], dataObj.userid_mapped_data['4159']])#np.random.choice(range(dataObj.n_users), config.n_users_per_round, replace=False)
             overall_optimal_reward[i] = np.take(self.optimal_rewards, user_ids).sum()
             # Iterate over all policies
             for j in range(len(self.rankers)):
@@ -72,7 +72,7 @@ class OnlineSimulator():
             return optimal_rankings, optimal_scores
         elif config.optimal_ranker == 'topical_coverage':
             n_users = self.user_features.shape[0]
-            optimal_rankings, optimal_scores = np.zeros((n_users, config.list_size), dtype=int), np.zeros((n_users, config.list_size, self.item_features.shape[1]))
+            optimal_rankings, optimal_scores = np.zeros((n_users, config.list_size), dtype=int), np.zeros((n_users, config.list_size))
             tie_breaker = self.prng.rand(len(self.item_features))
             for i in range(n_users):
                 # gain_in_topic_coverage_t = []
@@ -87,15 +87,15 @@ class OnlineSimulator():
                     for tr in tmp_rank:
                         if tr not in ranking:
                             ranking.append(tr)
-                            # optimal_scores[i, j] = self.user_features[i].dot(gain_in_topic_coverage[tr].T)
-                            optimal_scores[i, j] = gain_in_topic_coverage[tr]
+                            optimal_scores[i, j] = self.user_features[i].dot(gain_in_topic_coverage[tr].T)
+                            # optimal_scores[i, j] = gain_in_topic_coverage[tr]
                             break
                     coverage = AbstractRanker.ranking_coverage(self.item_features[ranking])
                 optimal_rankings[i] = np.asarray(ranking)
             return optimal_rankings, optimal_scores
         elif config.optimal_ranker == 'hybrid':
             n_users = self.user_features.shape[0]
-            optimal_rankings, optimal_scores = np.zeros((n_users, config.list_size), dtype=int), np.zeros((n_users, config.list_size), dataObj.feature_data['train_item_topical_features'].shape[1] + dataObj.feature_data['train_item_latent_features'].shape[1])
+            optimal_rankings, optimal_scores = np.zeros((n_users, config.list_size), dtype=int), np.zeros((n_users, config.list_size))
             for i in range(n_users):
                 # x = dataObj.feature_data['test_item_topical_features']
                 # z = dataObj.feature_data['test_item_latent_features']
@@ -126,10 +126,11 @@ class OnlineSimulator():
                             break
                     coverage = AbstractRanker.ranking_coverage(dataObj.feature_data['test_item_topical_features'][ranking])
                 gain_in_topic_coverage_t = np.asarray(gain_in_topic_coverage_t)
-                # delta = np.zeros((k, self.n_topics + self.d_feature))
-                self.optimal_scores[:, :dataObj.feature_data['test_item_topical_features'].shape[1]] = gain_in_topic_coverage_t
+                delta = np.zeros((config.list_size, dataObj.feature_data['test_item_topical_features'].shape[1] + dataObj.feature_data['train_item_latent_features'].shape[1]))
+                delta[:, :dataObj.feature_data['test_item_topical_features'].shape[1]] = gain_in_topic_coverage_t
                 # self.optimal_scores[:, dataObj.feature_data['test_item_topical_features'].shape[1]:] = dataObj.feature_data['test_item_latent_features'][ranking]
-                self.optimal_scores[:, dataObj.feature_data['test_item_topical_features'].shape[1]:] = dataObj.feature_data['train_item_latent_features'][ranking]
+                delta[:, dataObj.feature_data['test_item_topical_features'].shape[1]:] = dataObj.feature_data['train_item_latent_features'][ranking]
+                optimal_scores[i, :] = self.user_features[i].dot(delta.T)
                 return optimal_rankings, optimal_scores
 
     def compute_rewards(self, config, dataObj, batch_users, rankings):
@@ -154,10 +155,10 @@ class OnlineSimulator():
             n_users = batch_user_features.shape[0]
             scores = np.zeros((n_users, config.list_size))
             for i in range(n_users):
-                topic_coverage = self.__convert_to_topic_coverage(dataObj.feature_data['test_item_topical_features'][rankings])
+                topic_coverage = self.__convert_to_topic_coverage(dataObj.feature_data['test_item_topical_features'][rankings[i]])
                 item_full_feature = np.zeros((config.list_size, dataObj.feature_data['test_item_topical_features'].shape[1] + dataObj.feature_data['train_item_latent_features'].shape[1]))
                 item_full_feature[:, :dataObj.feature_data['test_item_topical_features'].shape[1]] = topic_coverage
-                item_full_feature[:, dataObj.feature_data['test_item_topical_features'].shape[1]:] = dataObj.feature_data['train_item_latent_features'][rankings]
+                item_full_feature[:, dataObj.feature_data['test_item_topical_features'].shape[1]:] = dataObj.feature_data['train_item_latent_features'][rankings[i]]
                 scores[i] = batch_user_features[i].dot(item_full_feature.T)
             return self.click_simulator.get_feedback(scores)
 
